@@ -1,12 +1,12 @@
 /**
  * The Python Interface for JavaScript
  */
-
 const util = require('util')
-if (typeof performance === 'undefined') var { performance } = require('perf_hooks')
-const log = () => { }
 const errors = require('./errors')
-const REQ_TIMEOUT = 100000
+if (typeof performance === 'undefined') var { performance } = require('perf_hooks')
+
+const log = () => { }
+const REQ_TIMEOUT = isNaN(process.env.REQ_TIMEOUT) ? 100000 : parseInt(process.env.REQ_TIMEOUT)
 
 class BridgeException extends Error {
   constructor (...a) {
@@ -37,7 +37,7 @@ class PythonException extends Error {
 
 async function waitFor (cb, withTimeout, onTimeout) {
   let t
-  if (withTimeout === Infinity) return new Promise(resolve => cb(resolve))
+  if ((withTimeout === Infinity) || (withTimeout === 0)) return new Promise(resolve => cb(resolve))
   const ret = await Promise.race([
     new Promise(resolve => cb(resolve)),
     new Promise(resolve => { t = setTimeout(() => resolve('timeout'), withTimeout) })
@@ -136,19 +136,17 @@ class PyBridge {
         ) {
           const ffid = ++this.jsi.ffid
           this.jsi.m[ffid] = v
-          this.queueForCollection(ffid, v)
           return { ffid }
         }
       }
       return v
     })
 
-    const stacktrace = new PythonException(stack)
-
     const resp = await waitFor(resolve => this.com.writeRaw(payload, r, resolve), timeout || REQ_TIMEOUT, () => {
       throw new BridgeException(`Attempt to access '${stack.join('.')}' failed.`)
     })
     if (resp.key === 'error') {
+      const stacktrace = new PythonException(stack)
       stacktrace.setPythonTrace(resp.sig)
       throw stacktrace
     }
